const path = require('path');
const UglifyJsPlugin = require('uglifyjs-webpack-plugin');
const WebpackObfuscator = require('webpack-obfuscator');


module.exports = {
    mode: 'production',
    entry: {
        video: './video.js',
    },
    output: {
        path: path.resolve(__dirname),
        filename: '[name].bundle.js',
    },

    optimization: {
        minimizer: [
            new UglifyJsPlugin({
                uglifyOptions: {
                    mangle: {
                        reserved: ['detail', 'search'], // 保留指定函数名
                    },
                    compress: {
                        // 压缩选项配置
                        unused: true,
                        dead_code: true,
                        // drop_console: true,
                    },
                    output: {
                        beautify: false, // 禁用美化输出
                    },
                },
            }),
        ],
    },
    plugins: [
        new WebpackObfuscator({
            rotateUnicodeArray: true,
            compact: true,
            stringArray: true,
            stringArrayEncoding: ['base64'],
        }),
    ],
    devtool: 'source-map'
};
